# -*- coding: utf-8 -*-
import datetime

from kinder.core.dict.models import UnitKind
from gisdo.queue.queue_conf import GisdoContainer
from gisdo.queue.runtime_filters import DateYearFilter
from gisdo.queue.context import Context


def get_queue_index(
        index_number, unit, age_range=None, on_date=datetime.date.today,
        check_unit=True):
    """Вычисление новых показателей по очереди"""

    qs = get_queue_index_collection(
        index_number, unit, age_range=age_range, on_date=on_date,
        check_unit=check_unit)

    return qs.count()


def get_queue_index_collection(
        index_number, unit, age_range=None, on_date=datetime.date.today,
        check_unit=True):
    """Вычисление новых показателей по очереди"""

    assert 'p{0}'.format(
        index_number.replace('.', '_')
    ) in GisdoContainer.index_filters, "Queue config failed"

    # Формирование контекста на основе показателей.
    ctx = Context(unit, on_date=on_date, first_dou_only=True)
    if age_range is not None:
        ctx = ctx.add_filters(DateYearFilter(age_range))

    # Получение билдера
    cont = GisdoContainer()
    builder = cont.get_builder(index_number)

    # Построение QuerySet-а
    qs = builder.build(ctx)
    if check_unit:
        qs = qs.filter(
            declarationunit__unit_id=unit.id,
            declarationunit__ord=1,
            declarationunit__unit__kind_id=UnitKind.DOU)

    return qs
